==> jc-1.4.0.tar.gz: gnu/xml/dom/DomXPathExpression.h <==
// class gnu.xml.dom.DomXPathExpression

// class file dependencies
// @dep_class f3b1dfb6fd265a90 gnu_xml_dom_DomXPathExpression
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomXPathExpression_H_
#define _JC_gnu_xml_dom_DomXPathExpression_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_xpath_XPathExpression$object;
struct _jc_org_w3c_dom_Node$object;
struct _jc_org_w3c_dom_xpath_XPathNSResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomXPathExpression$sub_refs	_jc_gnu_xml_dom_DomXPathExpression$sub_refs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs	_jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$refs	_jc_gnu_xml_dom_DomXPathExpression$refs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$nonrefs	_jc_gnu_xml_dom_DomXPathExpression$nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$object	_jc_gnu_xml_dom_DomXPathExpression$object;

typedef const struct _jc_gnu_xml_dom_DomXPathExpression$vmethods	_jc_gnu_xml_dom_DomXPathExpression$vmethods;
typedef const struct _jc_gnu_xml_dom_DomXPathExpression$vtable	_jc_gnu_xml_dom_DomXPathExpression$vtable;
typedef const struct _jc_gnu_xml_dom_DomXPathExpression$vtype	_jc_gnu_xml_dom_DomXPathExpression$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomXPathExpression$method$_init$14a124c51c8cc746(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_DomXPathExpression$method$evaluate$7532129f49cc376f(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomXPathExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomXPathExpression$method_info$evaluate$7532129f49cc376f;
extern _jc_method _jc_gnu_xml_dom_DomXPathExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomXPathExpression$vmethods {
	struct _jc_java_lang_Object$object	*(*evaluate$7532129f49cc376f)(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomXPathExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomXPathExpression$vmethods	gnu_xml_dom_DomXPathExpression;
};

// Vtype
struct _jc_gnu_xml_dom_DomXPathExpression$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomXPathExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathExpression$sub_refs {
	struct _jc_gnu_xml_dom_DomDocument$object	*doc;
	struct _jc_object	*expression;
	struct _jc_object	*resolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathExpression$refs {
    _jc_gnu_xml_dom_DomXPathExpression$sub_refs	gnu_xml_dom_DomXPathExpression;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs	gnu_xml_dom_DomXPathExpression;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomXPathExpression$object {
	_jc_gnu_xml_dom_DomXPathExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomXPathExpression$vtype	*vtype;
	_jc_gnu_xml_dom_DomXPathExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomXPathExpression$vtype _jc_gnu_xml_dom_DomXPathExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomXPathExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomXPathExpression$class_object;

#endif	/* _JC_gnu_xml_dom_DomXPathExpression_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomXPathExpression.h <==
// class gnu.xml.dom.DomXPathExpression

// class file dependencies
// @dep_class f3b1dfb6fd265a90 gnu_xml_dom_DomXPathExpression
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomXPathExpression_H_
#define _JC_gnu_xml_dom_DomXPathExpression_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_xpath_XPathExpression$object;
struct _jc_org_w3c_dom_Node$object;
struct _jc_org_w3c_dom_xpath_XPathNSResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomXPathExpression$sub_refs	_jc_gnu_xml_dom_DomXPathExpression$sub_refs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs	_jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$refs	_jc_gnu_xml_dom_DomXPathExpression$refs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$nonrefs	_jc_gnu_xml_dom_DomXPathExpression$nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathExpression$object	_jc_gnu_xml_dom_DomXPathExpression$object;

typedef const struct _jc_gnu_xml_dom_DomXPathExpression$vmethods	_jc_gnu_xml_dom_DomXPathExpression$vmethods;
typedef const struct _jc_gnu_xml_dom_DomXPathExpression$vtable	_jc_gnu_xml_dom_DomXPathExpression$vtable;
typedef const struct _jc_gnu_xml_dom_DomXPathExpression$vtype	_jc_gnu_xml_dom_DomXPathExpression$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomXPathExpression$method$_init$14a124c51c8cc746(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_DomXPathExpression$method$evaluate$7532129f49cc376f(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomXPathExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomXPathExpression$method_info$evaluate$7532129f49cc376f;
extern _jc_method _jc_gnu_xml_dom_DomXPathExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomXPathExpression$vmethods {
	struct _jc_java_lang_Object$object	*(*evaluate$7532129f49cc376f)(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *, struct _jc_object *, jshort, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_dom_DomXPathExpression$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomXPathExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomXPathExpression$vmethods	gnu_xml_dom_DomXPathExpression;
};

// Vtype
struct _jc_gnu_xml_dom_DomXPathExpression$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomXPathExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathExpression$sub_refs {
	struct _jc_gnu_xml_dom_DomDocument$object	*doc;
	struct _jc_object	*expression;
	struct _jc_object	*resolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathExpression$refs {
    _jc_gnu_xml_dom_DomXPathExpression$sub_refs	gnu_xml_dom_DomXPathExpression;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomXPathExpression$sub_nonrefs	gnu_xml_dom_DomXPathExpression;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomXPathExpression$object {
	_jc_gnu_xml_dom_DomXPathExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomXPathExpression$vtype	*vtype;
	_jc_gnu_xml_dom_DomXPathExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomXPathExpression$vtype _jc_gnu_xml_dom_DomXPathExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomXPathExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomXPathExpression$class_object;

#endif	/* _JC_gnu_xml_dom_DomXPathExpression_H_ */
